@@ -1,5 +1,5 @@
 package BalanceOfPower::Commands;
-$BalanceOfPower::Commands::VERSION = '0.300051';
+$BalanceOfPower::Commands::VERSION = '0.300100';
 use v5.10;
 use Moo;
 use IO::Prompter [-stdio];
@@ -516,6 +516,11 @@ COMMANDS
             $result = { status => -1 };
         }
     }
+    elsif($query eq "targets")
+    {
+        print $self->world->print_targets($self->get_active_player()->name);
+        $result = { status => 1 };
+    }
     else
     {
         my $nation_query = $self->world->correct_nation_name($query);
