@@ -1,5 +1,5 @@
 package BalanceOfPower::Constants;
-$BalanceOfPower::Constants::VERSION = '0.300051';
+$BalanceOfPower::Constants::VERSION = '0.300100';
 use strict;
 use warnings;
 
@@ -113,8 +113,8 @@ use constant MILITARY_AID_DIPLOMACY_FACTOR => 7;
 use constant STOCK_INFLUENCE_FACTOR => .5;
 use constant START_STOCKS => [ 8, 10, 12 ];
 use constant START_PLAYER_MONEY => 1000;
-use constant WAR_BOND_COST => 10;
-use constant WAR_BOND_GAIN => 20;
+use constant WAR_BOND_COST => 50;
+use constant WAR_BOND_GAIN => 90;
 use constant INFLUENCE_COST => 1;
 use constant MAX_BUY_STOCK => 4;
 
@@ -148,6 +148,7 @@ use constant PROGRESS_INCREMENT => .1;
 use constant TREATY_LIMIT_PROGRESS_STEP => 0.4;
 use constant TREATIES_FOR_PROGRESS_STEP => 5;
 use constant MAX_AFFORDABLE_PROGRESS => 0.8;
+use constant TIME_FOR_TARGET => 16;
 
 our @EXPORT_OK = ('MIN_EXPORT_QUOTE', 
                   'MAX_EXPORT_QUOTE',
@@ -269,5 +270,6 @@ our @EXPORT_OK = ('MIN_EXPORT_QUOTE',
                   'CIVIL_WAR_WEALTH_MALUS',
                   'INFLUENCE_COST',
                   'MAX_BUY_STOCK',
+                  'TIME_FOR_TARGET'
                 );
 our %EXPORT_TAGS = ( all => \@EXPORT_OK );
