@@ -1,5 +1,5 @@
 package BalanceOfPower::Role::Recorder;
-$BalanceOfPower::Role::Recorder::VERSION = '0.300051';
+$BalanceOfPower::Role::Recorder::VERSION = '0.300100';
 use strict;
 use v5.10;
 
@@ -10,7 +10,7 @@ use BalanceOfPower::Executive;
 requires 'dump_events';
 requires 'load_events';
 
-my $dump_version = 2;
+my $dump_version = 3;
 
 
 sub dump
@@ -72,6 +72,7 @@ sub load_players
 {
     my $self = shift;
     my $data = shift;
+    my $version = shift;
     $data .= "EOF\n";
     my $player_data = "";
     foreach my $l (split "\n", $data)
@@ -81,7 +82,7 @@ sub load_players
         {
             if($player_data)
             {
-                my $player = BalanceOfPower::Player->load($player_data);
+                my $player = BalanceOfPower::Player->load($player_data, $version, $self);
                 push @{$self->players}, $player;
             }
             $player_data = $l . "\n";
@@ -217,7 +218,7 @@ sub load_world
             }
             elsif($target eq 'PLAYERS')
             {
-                $world->load_players($data);
+                $world->load_players($data, $version);
             }
             elsif($target eq 'DIPLOMATIC RELATIONS')
             {
