@@ -1,5 +1,5 @@
 package BalanceOfPower::World;
-$BalanceOfPower::World::VERSION = '0.300051';
+$BalanceOfPower::World::VERSION = '0.300100';
 use strict;
 use v5.10;
 
@@ -114,7 +114,7 @@ sub get_nation
     }
     else
     {
-        say "Cannot found $nation";
+        say "Cannot find $nation";
         return undef;
     }
 }
@@ -285,6 +285,7 @@ sub post_decisions_elaborations
     $self->civil_warfare();
     $self->warfare();
     $self->internal_conflict();
+    $self->player_targets();
     $self->register_global_data();
     $self->collect_events();
 }
